==> rechn_mgm_user_area-0.1.17.gem: config/routes.rb <==
RechnMgmUserArea::Engine.routes.draw do
    get 'exports/search'
    get 'exports/generate_excel'

    scope 'users' do
        get    "/"                      => "users#index", as: :user_root
        get    "/"                      => "users#index", as: :user
        post   "/"                      => "users#create"
        get    "/new"                   => "users#new"
        get    ":id/edit"               => "users#edit", as: :edit_user
        get    ":id/memberships"        => "users#memberships"
        get    ":id"                    => "users#show"
        patch  ":id"                    => "users#update"
        put    ":id"                    => "users#update"
        delete ":id"                    => "users#destroy"
        get    ":id/change_role"        => "users#change_role_dialog",                  as: :change_role_dialog
        post   ":id/change_role"        => "users#change_role",                         as: :change_role
    end
    scope 'user_assignment' do
        delete ":user_id"               => "users#delete_user_membership",              as: :remove_user_assignment
        delete "invitation/:id"         => "users#delete_invitation", as: :remove_invitation
    end
    scope 'organisation_assignment' do
        delete ":membership_id"         => "users#delete_membership_to_organisation",   as: :remove_membership
    end

    scope 'organisation' do
        get     "/new_invitation"       => "organisations#new_invitation",              as: :new_invitation
        post    "/create_invitation"    => "organisations#create_invitation",           as: :create_invitation
        put     "/:user_id/resend"       => "organisations#resend_invitation",           as: :resend_invitation
    end

    #delete '/organisation_user/:id'     => 'users#remove_assignement'

    scope '/api', :constraints => { :format => 'json' }  do
        scope '/v1' do
            get 'getUser'               => "users#show_me"
            get 'getUsers'              => "users#index"
            get 'getUser/:id'           => "users#show"
            get 'getFavorites'          => "users#favorites"
            put 'setFavorite/:id'       => "users#set_favorite"
            put 'removeFavorite/:id'    => "users#remove_favorite"
            patch "frontend_url"        => "users#update_frontend_url"
            put "frontend_url"          => "users#update_frontend_url"
        end
    end
end

==> rechn_mgm_user_area-0.1.26.gem: config/routes.rb <==
RechnMgmUserArea::Engine.routes.draw do
    get 'exports/search'
    get 'exports/generate_excel'

    scope 'users' do
        get    "/"                      => "users#index",                               as: :user_root
        get    "/"                      => "users#index",                               as: :user
        post   "/"                      => "users#create"
        get    "/new"                   => "users#new"
        get    ":id/edit"               => "users#edit", as: :edit_user
        get    ":id/memberships"        => "users#memberships"
        get    ":id"                    => "users#show"
        patch  ":id"                    => "users#update"
        put    ":id"                    => "users#update"
        delete ":id"                    => "users#destroy"
        get    ":id/change_role"        => "users#change_role_dialog",                  as: :change_role_dialog
        post   ":id/change_role"        => "users#change_role",                         as: :change_role
    end
    scope 'user_assignment' do
        delete ":user_id"               => "users#delete_user_membership",              as: :remove_user_assignment
        delete "invitation/:id"         => "users#delete_invitation",                   as: :remove_invitation
    end
    scope 'organisation_assignment' do
        delete ":membership_id"         => "users#delete_membership_to_organisation",   as: :remove_membership
    end

    scope 'organisation' do
        get    "/"                                          => "organisations#index",                       as: :organisation
        get     "new_invitation"                            => "organisations#new_invitation",              as: :new_invitation
        post    "create_invitation"                         => "organisations#create_invitation",           as: :create_invitation
        put     ":user_id/resend"                           => "organisations#resend_invitation",           as: :resend_invitation
        put     "switch_organisation"                       => "organisations#switch_organisation",         as: :switch_organisation
    end

    #delete '/organisation_user/:id'     => 'users#remove_assignement'

    scope '/api', :constraints => { :format => 'json' }  do
        scope '/v1' do
            get 'getUser'               => "users#show_me"
            get 'getUsers'              => "users#index"
            get 'getUser/:id'           => "users#show"
            get 'getFavorites'          => "users#favorites"
            put 'setFavorite/:id'       => "users#set_favorite"
            put 'removeFavorite/:id'    => "users#remove_favorite"
            patch "frontend_url"        => "users#update_frontend_url"
            put "frontend_url"          => "users#update_frontend_url"
        end
    end
end
